"""Control Operating Systems."""

from __future__ import annotations

from abc import ABC, abstractmethod
from typing import TYPE_CHECKING

from rwx.os.debian import Debian

if TYPE_CHECKING:
    from pathlib import Path


class OS(ABC):
    """Operating System."""

    def __init__(self, path: Path) -> None:
        """Set root."""
        self.root = path
        self.name = self.get_name()

    @abstractmethod
    def get_name(self) -> str:
        """Return mandatory name."""

    @staticmethod
    def from_path(path: Path) -> OS:
        """Initialize from an already existing path."""
        return Debian(path)
